<?php

namespace Drupal\notify_to_slack\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configuration form to collect the url, channel name and other details.
 */
class SettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'notify_slack_admin_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'notify_to_slack.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('notify_to_slack.settings');
    $form['notify_slack_incoming_webhook_url'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Incoming webhook url'),
      '#default_value' => $config->get('notify_slack_incoming_webhook_url'),
      '#description' => $this->t('Enter incoming webhook url from slack account'),
    ];
    $form['notify_slack_channel_for_message'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Slack channel'),
      '#default_value' => $config->get('notify_slack_channel_for_message'),
      '#description' => $this->t('Enter slack channel for notification'),
    ];
    $form['webhook_name'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Name of the Bot'),
      '#default_value' => $config->get('webhook_name'),
      '#description' => $this->t('Enter display name of the notifier'),
    ];
    $contentTypes = \Drupal::service('entity.manager')->getStorage('node_type')->loadMultiple();
    $contentTypesList = [];
    foreach ($contentTypes as $contentType) {
      $contentTypesList[$contentType->id()] = $contentType->label();
    }
    $form['node_to_notify_on_slack'] = [
      '#type' => 'checkboxes',
      '#title' => $this->t('Content type to notify on slack'),
      '#default_value' => $config->get('node_to_notify_on_slack'),
      '#description' => $this->t('Content type to notify on slack eg. Article'),
      '#options' => $contentTypesList,
    ];
    $form['state_to_notify'] = [
      '#type' => 'checkboxes',
      '#title' => $this->t('Select the states which need notification'),
      '#default_value' => $config->get('state_to_notify'),
      '#options' => [
        'create'=>$this->t('Create'),
        'update'=>$this->t('Update'),
        'delete'=>$this->t('Delete')

      ],
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = \Drupal::service('config.factory')->getEditable('notify_to_slack.settings');
    $config->set('notify_slack_incoming_webhook_url', $form_state->getValue('notify_slack_incoming_webhook_url'));
    $config->set('notify_slack_channel_for_message', $form_state->getValue('notify_slack_channel_for_message'));
    $config->set('node_to_notify_on_slack', $form_state->getValue('node_to_notify_on_slack'));
    $config->set('webhook_name', $form_state->getValue('webhook_name'));
    $config->set('state_to_notify', $form_state->getValue('state_to_notify'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
